@@ -95,14 +95,18 @@ class H2Protocol(asyncio.Protocol):
     def data_received(self, data: bytes) -> None:
         for event in self.conn.receive_data(data):
             if isinstance(event, ResponseReceived):
-                headers = dict(event.headers)
+                headers = dict(event.headers)  # type: ignore
                 self.on_response_received(headers)
             elif isinstance(event, DataReceived):
-                self.on_data_received(event.data, event.stream_id)
+                self.on_data_received(
+                    event.data, event.stream_id  # type: ignore
+                )
             elif isinstance(event, RemoteSettingsChanged):
-                self.on_remote_settings_changed(event.changed_settings)
+                self.on_remote_settings_changed(
+                    event.changed_settings  # type: ignore
+                )
             elif isinstance(event, StreamEnded):
-                self.on_stream_ended(event.stream_id)
+                self.on_stream_ended(event.stream_id)  # type: ignore
             elif isinstance(event, ConnectionTerminated):
                 self.on_connection_terminated(event)
             elif isinstance(event, WindowUpdated):
@@ -439,6 +443,7 @@ class APNsBaseConnectionPool:
     ) -> APNsBaseClientProtocol:
         assert self.proxy_host is not None, "proxy_host must be set"
         assert self.proxy_port is not None, "proxy_port must be set"
+        assert self.ssl_context is not None, "ssl_context must be set"
 
         _, protocol = await self.loop.create_connection(
             protocol_factory=partial(
@@ -500,9 +505,9 @@ class APNsCertConnectionPool(APNsBaseConnectionPool):
     async def create_connection(self) -> APNsBaseClientProtocol:
         apns_protocol_factory = partial(
             self.protocol_class,
-            self.apns_topic,
+            self.apns_topic,  # type: ignore
             self.loop,
-            self.discard_connection,
+            self.discard_connection,  # type: ignore
         )
 
         if self.proxy_host and self.proxy_port:
@@ -525,7 +530,7 @@ class APNsCertConnectionPool(APNsBaseConnectionPool):
 class APNsKeyConnectionPool(APNsBaseConnectionPool):
     def __init__(
         self,
-        key_file: str,
+        key: str,
         key_id: str,
         team_id: str,
         topic: str,
@@ -547,21 +552,19 @@ class APNsKeyConnectionPool(APNsBaseConnectionPool):
 
         self.ssl_context = ssl_context or ssl.create_default_context()
 
+        self.key = key
         self.key_id = key_id
         self.team_id = team_id
 
-        with open(key_file) as f:
-            self.key = f.read()
-
     async def create_connection(self) -> APNsBaseClientProtocol:
         auth_provider = JWTAuthorizationHeaderProvider(
             key=self.key, key_id=self.key_id, team_id=self.team_id
         )
         apns_protocol_factory = partial(
             self.protocol_class,
-            self.apns_topic,
+            self.apns_topic,  # type: ignore
             self.loop,
-            self.discard_connection,
+            self.discard_connection,  # type: ignore
             auth_provider,
         )
 
