@@ -5,6 +5,6 @@ logging.getLogger("hpack").setLevel(logging.CRITICAL)
 logger = logging.getLogger("aioapns")
 
 
-def set_hpack_debugging(value):
+def set_hpack_debugging(value: bool) -> None:
     if value:
         logging.getLogger("hpack").setLevel(logging.DEBUG)
